@@ -13,8 +13,9 @@ use super::mark;
 use super::site;
 use super::template;
 use super::vwiki;
+use crate::SyntaxHighlight;
 
-#[derive(Debug, Clone, PartialEq, Serialize)]
+#[derive(Debug, Clone, Serialize)]
 #[serde(deny_unknown_fields, default)]
 pub struct Config {
     pub source: path::PathBuf,
@@ -29,6 +30,8 @@ pub struct Config {
     pub liquid: template::LiquidBuilder,
     pub markdown: mark::MarkdownBuilder,
     pub vimwiki: vwiki::VimwikiBuilder,
+    #[serde(skip)]
+    pub syntax: std::sync::Arc<SyntaxHighlight>,
     pub assets: assets::AssetsBuilder,
     pub minify: cobalt_config::Minify,
 }
@@ -96,13 +99,23 @@ impl Config {
         let includes_path = source.join(includes_dir);
         let layouts_path = source.join(layouts_dir);
 
+        let mut highlight = SyntaxHighlight::new();
+        let syntaxes_path = source.join("_syntaxes");
+        if syntaxes_path.exists() {
+            highlight.load_custom_syntaxes(&syntaxes_path);
+        }
+
+        let syntax = std::sync::Arc::new(highlight);
+
         let liquid = template::LiquidBuilder {
             includes_path,
+            syntax: syntax.clone(),
             theme: syntax_highlight
                 .enabled
                 .then(|| syntax_highlight.theme.clone()),
         };
         let markdown = mark::MarkdownBuilder {
+            syntax: syntax.clone(),
             theme: syntax_highlight
                 .enabled
                 .then(|| syntax_highlight.theme.clone()),
@@ -125,6 +138,7 @@ impl Config {
             liquid,
             markdown,
             vimwiki,
+            syntax,
             assets,
             minify,
         };
