@@ -8,6 +8,8 @@ use crate::error::Result;
 use failure::ResultExt;
 use ignore::gitignore::{Gitignore, GitignoreBuilder};
 use ignore::Match;
+use log::debug;
+use log::trace;
 use normalize_line_endings::normalized;
 use walkdir::{DirEntry, WalkDir};
 
@@ -125,9 +127,7 @@ impl Files {
     }
 
     pub fn subtree(&self) -> &path::Path {
-        self.subtree
-            .as_deref()
-            .unwrap_or_else(|| self.root_dir.as_path())
+        self.subtree.as_deref().unwrap_or(self.root_dir.as_path())
     }
 
     pub fn includes_file(&self, file: &path::Path) -> bool {
@@ -154,7 +154,7 @@ impl Files {
         self.includes_path(dir, is_dir)
     }
 
-    pub fn files(&self) -> FilesIterator {
+    pub fn files(&self) -> FilesIterator<'_> {
         FilesIterator::new(self)
     }
 
@@ -273,7 +273,11 @@ pub fn copy_file(src_file: &path::Path, dest_file: &path::Path) -> Result<()> {
             .with_context(|_| failure::format_err!("Could not create {}", parent.display()))?;
     }
 
-    debug!("Copying {:?} to {:?}", src_file, dest_file);
+    debug!(
+        "Copying `{}` to `{}`",
+        src_file.display(),
+        dest_file.display()
+    );
     fs::copy(src_file, dest_file).with_context(|_| {
         failure::format_err!(
             "Could not copy {} into {}",
@@ -308,6 +312,8 @@ fn write_document_file_internal(content: &str, dest_file: &path::Path) -> Result
 
 #[cfg(test)]
 mod tests {
+    #![allow(clippy::bool_assert_comparison)]
+
     use super::*;
 
     macro_rules! assert_includes_dir {
