@@ -3,11 +3,12 @@ use std::collections::HashMap;
 use std::default::Default;
 use std::path::Path;
 
-use chrono::{Datelike, Timelike};
 use failure::ResultExt;
+use lazy_static::lazy_static;
 use liquid::model::Value;
 use liquid::Object;
 use liquid::ValueView;
+use log::trace;
 use regex::Regex;
 
 use crate::cobalt_model;
@@ -37,10 +38,10 @@ fn minify_if_enabled(
 #[cfg(feature = "html-minifier")]
 fn minify_if_enabled(
     html: String,
-    context: &RenderContext,
+    context: &RenderContext<'_>,
     file_path: &relative_path::RelativePath,
 ) -> Result<String> {
-    let extension = file_path.extension().unwrap_or_else(Default::default);
+    let extension = file_path.extension().unwrap_or_default();
     if context.minify.html && (extension == "html" || extension == "htm") {
         Ok(html_minifier::minify(html)?)
     } else {
@@ -174,7 +175,7 @@ fn document_attributes(
 pub struct Document {
     pub url_path: String,
     pub file_path: relative_path::RelativePathBuf,
-    pub content: kstring::KString,
+    pub content: liquid::model::KString,
     pub attributes: Object,
     pub front: cobalt_model::Frontmatter,
 }
@@ -221,8 +222,7 @@ impl Document {
         let guid = rss::GuidBuilder::default()
             .value(link.clone())
             .permalink(true)
-            .build()
-            .map_err(failure::err_msg)?;
+            .build();
 
         let item = rss::ItemBuilder::default()
             .title(Some(self.front.title.as_str().to_owned()))
@@ -230,8 +230,7 @@ impl Document {
             .guid(Some(guid))
             .pub_date(self.front.published_date.map(|date| date.to_rfc2822()))
             .description(self.description_to_str())
-            .build()
-            .map_err(failure::err_msg)?;
+            .build();
         Ok(item)
     }
 
@@ -268,7 +267,9 @@ impl Document {
         let mut url = sitemap::structs::UrlEntry::builder();
         url = url.loc(link);
         if let Some(date) = self.front.published_date {
-            url = url.lastmod(*date);
+            let date = vimwiki::vendor::chrono::DateTime::parse_from_rfc2822(&date.to_rfc2822())
+                .expect("chrono/time compatible RFC 2822 implementations");
+            url = url.lastmod(date);
         }
         writer.url(url)?;
         Ok(())
@@ -300,7 +301,7 @@ impl Document {
     /// Takes `content` string and returns rendered HTML. This function doesn't
     /// take `"extends"` attribute into account. This function can be used for
     /// rendering content or excerpt.
-    fn render_html(&self, content: &str, context: &RenderContext) -> Result<String> {
+    fn render_html(&self, content: &str, context: &RenderContext<'_>) -> Result<String> {
         let html = if self.front.templated {
             let template = context.parser.parse(content)?;
             template.render(context.globals)?
@@ -323,7 +324,7 @@ impl Document {
     /// given, or extracted from the content, if `excerpt_separator` is not
     /// empty. When neither condition applies, the excerpt is set to the `Nil`
     /// value.
-    pub fn render_excerpt(&mut self, context: &RenderContext) -> Result<()> {
+    pub fn render_excerpt(&mut self, context: &RenderContext<'_>) -> Result<()> {
         let value = if let Some(excerpt_str) = self.front.excerpt.as_ref() {
             let excerpt = self.render_html(excerpt_str, context)?;
             Value::scalar(excerpt)
@@ -346,7 +347,7 @@ impl Document {
     /// Renders the content and adds it to attributes of the document.
     ///
     /// When we say "content" we mean only this document without extended layout.
-    pub fn render_content(&mut self, context: &RenderContext) -> Result<()> {
+    pub fn render_content(&mut self, context: &RenderContext<'_>) -> Result<()> {
         let content_html = self.render_html(&self.content, context)?;
         self.attributes
             .insert("content".into(), Value::scalar(content_html));
@@ -360,7 +361,7 @@ impl Document {
     /// * layout may be inserted to layouts cache
     pub fn render(
         &mut self,
-        context: &RenderContext,
+        context: &RenderContext<'_>,
         layouts: &HashMap<String, String>,
     ) -> Result<String> {
         if let Some(ref layout) = self.front.layout {
@@ -383,8 +384,8 @@ impl Document {
             Ok(content_html)
         } else {
             let path = &[
-                kstring::KStringCow::from_static("page").into(),
-                kstring::KStringCow::from_static("content").into(),
+                liquid::model::KStringCow::from_static("page").into(),
+                liquid::model::KStringCow::from_static("content").into(),
             ];
             let content_html = liquid::model::try_find(context.globals, path)
                 .ok_or_else(|| failure::err_msg("Internal error: page isn't in globals"))?
